@@ -601,9 +601,12 @@ public class ResourcesPanel extends FramedPanel {
 	}
 
 	protected void requestRemove(ResourceTDDescriptor resourceTDDescriptor) {
-
+		ArrayList<ResourceTDDescriptor> resources=new ArrayList<ResourceTDDescriptor>();
+		resources.add(resourceTDDescriptor);
+		
+		
 		removeResourceSession = new RemoveResourceSession(trId,
-				resourceTDDescriptor);
+				resources);
 
 		TDGWTServiceAsync.INSTANCE.removeResource(removeResourceSession,
 				new AsyncCallback<Void>() {
